@@ -41,7 +41,7 @@
 
 #include <kurl.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 
 // Local includes.
