@@ -40,7 +40,7 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kurl.h>
 #include <kdialog.h>
 
