@@ -49,18 +49,18 @@
 // KDE includes.
 
 #include <knuminput.h>
-#include <klocale.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
 #include <kcursor.h>
 #include <kstandarddirs.h>
 #include <ktabwidget.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kurlrequester.h>
 #include <kurllabel.h>
-#include <kfiledialog.h>
-#include <kfile.h>
-#include <kmessagebox.h>
-#include <kglobalsettings.h>
+#include <tdefiledialog.h>
+#include <tdefile.h>
+#include <tdemessagebox.h>
+#include <tdeglobalsettings.h>
 #include <kiconloader.h>
 #include <ksqueezedtextlabel.h>
 
@@ -140,16 +140,16 @@ ImageEffect_ICCProof::ImageEffect_ICCProof(TQWidget* parent)
     TQPushButton *linHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     m_scaleBG->insert(linHistoButton, Digikam::HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( TQPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     m_scaleBG->insert(logHistoButton, Digikam::HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( TQPixmap( directory + "histogram-log.png" ) );
     logHistoButton->setToggleButton(true);
 
@@ -256,8 +256,8 @@ ImageEffect_ICCProof::ImageEffect_ICCProof(TQWidget* parent)
     lcmsLogoLabel->setAlignment( AlignTop | AlignRight );
     lcmsLogoLabel->setText(TQString());
     lcmsLogoLabel->setURL("http://www.littlecms.com");
-    KGlobal::dirs()->addResourceType("logo-lcms", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("logo-lcms", "logo-lcms.png");
+    TDEGlobal::dirs()->addResourceType("logo-lcms", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("logo-lcms", "logo-lcms.png");
     lcmsLogoLabel->setPixmap( TQPixmap( directory + "logo-lcms.png" ) );
     TQToolTip::add(lcmsLogoLabel, i18n("Visit Little CMS project website"));
 
@@ -272,7 +272,7 @@ ImageEffect_ICCProof::ImageEffect_ICCProof(TQWidget* parent)
 
     //---------- "Input" Page Setup ----------------------------------
 
-    m_toolBoxWidgets->insertItem(INPUTPAGE, inProfiles, SmallIconSet("camera"), i18n("Input Profile"));
+    m_toolBoxWidgets->insertItem(INPUTPAGE, inProfiles, SmallIconSet("camera-photo"), i18n("Input Profile"));
     TQWhatsThis::add(inProfiles, i18n("<p>Set here all parameters relevant of Input Color "
                     "Profiles.</p>"));
 
@@ -322,7 +322,7 @@ ImageEffect_ICCProof::ImageEffect_ICCProof(TQWidget* parent)
     //---------- "Workspace" Page Setup ---------------------------------
 
     m_toolBoxWidgets->insertItem(WORKSPACEPAGE, spaceProfiles, 
-                                 SmallIconSet("tablet"), i18n("Workspace Profile"));
+                                 SmallIconSet("input-tablet"), i18n("Workspace Profile"));
     TQWhatsThis::add(spaceProfiles, i18n("<p>Set here all parameters relevant to Color Workspace "
                     "Profiles.</p>"));
 
@@ -356,7 +356,7 @@ ImageEffect_ICCProof::ImageEffect_ICCProof(TQWidget* parent)
     //---------- "Proofing" Page Setup ---------------------------------
 
     m_toolBoxWidgets->insertItem(PROOFINGPAGE, proofProfiles, 
-                                 SmallIconSet("printer1"), i18n("Proofing Profile"));
+                                 SmallIconSet("printer"), i18n("Proofing Profile"));
     TQWhatsThis::add(proofProfiles, i18n("<p>Set here all parameters relevant to Proofing Color "
                     "Profiles.</p>"));
 
@@ -527,8 +527,8 @@ ImageEffect_ICCProof::~ImageEffect_ICCProof()
 
 void ImageEffect_ICCProof::readUserSettings()
 {
-    TQString defaultICCPath = KGlobalSettings::documentPath();
-    KConfig* config        = kapp->config();
+    TQString defaultICCPath = TDEGlobalSettings::documentPath();
+    TDEConfig* config        = kapp->config();
 
     // General settings of digiKam Color Management
     config->setGroup("Color Management");
@@ -604,7 +604,7 @@ void ImageEffect_ICCProof::readUserSettings()
 
 void ImageEffect_ICCProof::writeUserSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("colormanagement Tool Dialog");
     config->writeEntry("Settings Tab", m_toolBoxWidgets->currentIndex());
     config->writeEntry("Histogram Channel", m_channelCB->currentItem());
@@ -640,7 +640,7 @@ void ImageEffect_ICCProof::writeUserSettings()
 
 void ImageEffect_ICCProof::processLCMSURL(const TQString& url)
 {
-    KApplication::kApplication()->invokeBrowser(url);
+    TDEApplication::kApplication()->invokeBrowser(url);
 }
 
 void ImageEffect_ICCProof::slotSpotColorChanged(const Digikam::DColor &color)
@@ -1162,7 +1162,7 @@ bool ImageEffect_ICCProof::useDefaultProofProfile()
 
 void ImageEffect_ICCProof::slotUser3()
 {
-    KURL loadColorManagementFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadColorManagementFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                                 TQString( "*" ), this,
                                                 TQString( i18n("Color Management Settings File to Load")) );
     if( loadColorManagementFile.isEmpty() )
@@ -1238,7 +1238,7 @@ void ImageEffect_ICCProof::slotUser3()
 
 void ImageEffect_ICCProof::slotUser2()
 {
-    KURL saveColorManagementFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    KURL saveColorManagementFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                                 TQString( "*" ), this,
                                                 TQString( i18n("Color Management Settings File to Save")) );
     if( saveColorManagementFile.isEmpty() )
