@@ -40,12 +40,12 @@
 
 // KDE includes.
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kcolorbutton.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kpushbutton.h>
 #include <kstandarddirs.h>
 
@@ -146,7 +146,7 @@ RatioCropTool::RatioCropTool(TQObject* parent)
     m_preciseCrop = new TQCheckBox(i18n("Exact"), cropSelection);
     TQWhatsThis::add( m_preciseCrop, i18n("<p>Enable this option to force exact aspect ratio crop."));
 
-    m_orientLabel = new TQLabel(i18n("Qt::Orientation:"), cropSelection);
+    m_orientLabel = new TQLabel(i18n("Orientation:"), cropSelection);
     m_orientCB    = new RComboBox(cropSelection);
     m_orientCB->insertItem( i18n("Landscape"));
     m_orientCB->insertItem( i18n("Portrait"));
@@ -189,8 +189,8 @@ RatioCropTool::RatioCropTool(TQObject* parent)
     TQWhatsThis::add( m_widthInput, i18n("<p>Set here the width selection for cropping."));
 
     m_centerWidth = new TQToolButton(cropSelection);
-    KGlobal::dirs()->addResourceType("centerwidth", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("centerwidth", "centerwidth.png");
+    TDEGlobal::dirs()->addResourceType("centerwidth", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("centerwidth", "centerwidth.png");
     m_centerWidth->setPixmap(TQPixmap(directory + "centerwidth.png"));
     TQWhatsThis::add(m_centerWidth, i18n("<p>Set width position to center."));
 
@@ -211,8 +211,8 @@ RatioCropTool::RatioCropTool(TQObject* parent)
     TQWhatsThis::add( m_heightInput, i18n("<p>Set here the height selection for cropping."));
 
     m_centerHeight = new TQToolButton(cropSelection);
-    KGlobal::dirs()->addResourceType("centerheight", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("centerheight", "centerheight.png");
+    TDEGlobal::dirs()->addResourceType("centerheight", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("centerheight", "centerheight.png");
     m_centerHeight->setPixmap(TQPixmap(directory + "centerheight.png"));
     TQWhatsThis::add(m_centerHeight, i18n("<p>Set height position to center."));
 
@@ -398,7 +398,7 @@ RatioCropTool::~RatioCropTool()
 void RatioCropTool::readSettings()
 {
     TQColor defaultGuideColor(250, 250, 255);
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("aspectratiocrop Tool");
 
     // No guide lines per default.
@@ -462,7 +462,7 @@ void RatioCropTool::readSettings()
 
 void RatioCropTool::writeSettings()
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("aspectratiocrop Tool");
 
     if (m_originalIsLandscape)
@@ -592,7 +592,7 @@ void RatioCropTool::slotSelectionOrientationChanged(int newOrientation)
 
     setRatioCBText(newOrientation);
 
-    // Change Qt::Orientation ComboBox
+    // Change Orientation ComboBox
 
     m_orientCB->setCurrentItem(newOrientation);
 
