@@ -43,18 +43,18 @@
 
 // KDE includes.
 
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 #include <kactivelabel.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
-#include <kfiledialog.h>
-#include <kglobalsettings.h>
+#include <tdefiledialog.h>
+#include <tdeglobalsettings.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <kprogress.h>
 #include <kseparator.h>
 #include <kstandarddirs.h>
@@ -144,16 +144,16 @@ WhiteBalanceTool::WhiteBalanceTool(TQObject* parent)
     TQPushButton *linHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     m_scaleBG->insert(linHistoButton, HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( TQPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton( m_scaleBG );
     TQToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     m_scaleBG->insert(logHistoButton, HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( TQPixmap( directory + "histogram-log.png" ) );
     logHistoButton->setToggleButton(true);
 
@@ -228,8 +228,8 @@ WhiteBalanceTool::WhiteBalanceTool(TQObject* parent)
                                                  "<b>Daylight D65</b>: overcast sky light (6500K).<p>"
                                                  "<b>None</b>: no preset value."));
     m_pickTemperature = new TQPushButton(m_gboxSettings->plainPage());
-    KGlobal::dirs()->addResourceType("color-picker-grey", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("color-picker-grey", "color-picker-grey.png");
+    TDEGlobal::dirs()->addResourceType("color-picker-grey", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("color-picker-grey", "color-picker-grey.png");
     m_pickTemperature->setPixmap( TQPixmap( directory + "color-picker-grey.png" ) );
     m_pickTemperature->setToggleButton(true);
     TQToolTip::add( m_pickTemperature, i18n( "Temperature tone color picker." ) );
@@ -285,7 +285,7 @@ WhiteBalanceTool::WhiteBalanceTool(TQObject* parent)
                                                  " (E.V): </qt>"), m_gboxSettings->plainPage());
     m_mainExposureLabel  = new TQLabel(i18n("Main:"), m_gboxSettings->plainPage());
     m_autoAdjustExposure = new TQPushButton(m_gboxSettings->plainPage());
-    m_autoAdjustExposure->setPixmap(kapp->iconLoader()->loadIcon("run", (KIcon::Group)KIcon::Toolbar));
+    m_autoAdjustExposure->setPixmap(kapp->iconLoader()->loadIcon("system-run", (TDEIcon::Group)TDEIcon::Toolbar));
     TQToolTip::add( m_autoAdjustExposure, i18n( "Auto exposure adjustments" ) );
     TQWhatsThis::add( m_autoAdjustExposure, i18n("<p>With this button, you can automatically adjust Exposure "
                                                 "and Black Point values."));
@@ -737,7 +737,7 @@ void WhiteBalanceTool::slotResetSettings()
 
 void WhiteBalanceTool::readSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("whitebalance Tool");
     m_channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", 0));    // Luminosity.
     m_scaleBG->setButton(config->readNumEntry("Histogram Scale", HistogramWidget::LogScaleHistogram));
@@ -759,7 +759,7 @@ void WhiteBalanceTool::readSettings()
 
 void WhiteBalanceTool::writeSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("whitebalance Tool");
     config->writeEntry("Histogram Channel", m_channelCB->currentItem());
     config->writeEntry("Histogram Scale", m_scaleBG->selectedId());
@@ -778,7 +778,7 @@ void WhiteBalanceTool::writeSettings()
 
 void WhiteBalanceTool::slotLoadSettings()
 {
-    KURL loadWhiteBalanceFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadWhiteBalanceFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                              TQString( "*" ), kapp->activeWindow(),
                                              TQString( i18n("White Color Balance Settings File to Load")) );
     if( loadWhiteBalanceFile.isEmpty() )
@@ -820,7 +820,7 @@ void WhiteBalanceTool::slotLoadSettings()
 
 void WhiteBalanceTool::slotSaveAsSettings()
 {
-    KURL saveWhiteBalanceFile = KFileDialog::getSaveURL(KGlobalSettings::documentPath(),
+    KURL saveWhiteBalanceFile = KFileDialog::getSaveURL(TDEGlobalSettings::documentPath(),
                                              TQString( "*" ), kapp->activeWindow(),
                                              TQString( i18n("White Color Balance Settings File to Save")) );
     if( saveWhiteBalanceFile.isEmpty() )
