@@ -44,7 +44,7 @@
 // KDE includes.
 
 #include <kcursor.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 // Digikam includes.
 
