@@ -52,31 +52,31 @@ extern "C"
 
 #include <kprinter.h>
 #include <kkeydialog.h>
-#include <kdeversion.h>
-#include <kaction.h>
+#include <tdeversion.h>
+#include <tdeaction.h>
 #include <kedittoolbar.h>
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 #include <kcursor.h>
 #include <kstdaction.h>
-#include <kapplication.h>
-#include <kconfig.h>
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <kmenubar.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
+#include <tdemenubar.h>
 #include <kimageio.h>
-#include <kaccel.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
+#include <tdeaccel.h>
+#include <tdemessagebox.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
 #include <kiconloader.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/job.h>
 #include <kprotocolinfo.h>
-#include <kglobalsettings.h>
-#include <ktoolbar.h>
+#include <tdeglobalsettings.h>
+#include <tdetoolbar.h>
 #include <kstatusbar.h>
 #include <kprogress.h>
-#include <kwin.h>
+#include <twin.h>
 #include <kcombobox.h>
 
 // Local includes.
@@ -106,14 +106,14 @@ extern "C"
 #include "editorwindow.h"
 #include "editorwindow.moc"
 
-void qt_enter_modal( TQWidget *widget );
-void qt_leave_modal( TQWidget *widget );
+void tqt_enter_modal( TQWidget *widget );
+void tqt_leave_modal( TQWidget *widget );
 
 namespace Digikam
 {
 
 EditorWindow::EditorWindow(const char *name)
-            : KMainWindow(0, name, WType_TopLevel)
+            : TDEMainWindow(0, name, WType_TopLevel)
 {
     d = new EditorWindowPriv;
 
@@ -167,7 +167,7 @@ EditorStackView* EditorWindow::editorStackView() const
 void EditorWindow::setupContextMenu()
 {
     m_contextMenu         = new DPopupMenu(this);
-    KActionCollection *ac = actionCollection();
+    TDEActionCollection *ac = actionCollection();
     if( ac->action("editorwindow_backward") ) ac->action("editorwindow_backward")->plug(m_contextMenu);
     if( ac->action("editorwindow_forward") ) ac->action("editorwindow_forward")->plug(m_contextMenu);
     m_contextMenu->insertSeparator();
@@ -264,13 +264,13 @@ void EditorWindow::setupStandardActions()
     m_forwardAction = KStdAction::forward(TQT_TQOBJECT(this), TQT_SLOT(slotForward()),
                                   actionCollection(), "editorwindow_forward");
 
-    m_firstAction = new KAction(i18n("&First"), "start",
-                                KStdAccel::shortcut( KStdAccel::Home),
+    m_firstAction = new TDEAction(i18n("&First"), "go-first",
+                                TDEStdAccel::shortcut( TDEStdAccel::Home),
                                 TQT_TQOBJECT(this), TQT_SLOT(slotFirst()),
                                 actionCollection(), "editorwindow_first");
 
-    m_lastAction = new KAction(i18n("&Last"), "finish",
-                               KStdAccel::shortcut( KStdAccel::End),
+    m_lastAction = new TDEAction(i18n("&Last"), "go-last",
+                               TDEStdAccel::shortcut( TDEStdAccel::End),
                                TQT_TQOBJECT(this), TQT_SLOT(slotLast()),
                                actionCollection(), "editorwindow_last");
 
@@ -287,12 +287,12 @@ void EditorWindow::setupStandardActions()
     m_saveAsAction->setEnabled(false);
     m_revertAction->setEnabled(false);
 
-    d->filePrintAction = new KAction(i18n("Print Image..."), "fileprint",
+    d->filePrintAction = new TDEAction(i18n("Print Image..."), "document-print",
                                      CTRL+Key_P,
                                      TQT_TQOBJECT(this), TQT_SLOT(slotFilePrint()),
                                      actionCollection(), "editorwindow_print");
 
-    m_fileDeleteAction = new KAction(i18n("Move to Trash"), "edittrash",
+    m_fileDeleteAction = new TDEAction(i18n("Move to Trash"), "edittrash",
                                      Key_Delete,
                                      TQT_TQOBJECT(this), TQT_SLOT(slotDeleteCurrentItem()),
                                      actionCollection(), "editorwindow_delete");
@@ -306,8 +306,8 @@ void EditorWindow::setupStandardActions()
 
     d->copyAction->setEnabled(false);
 
-    m_undoAction = new KToolBarPopupAction(i18n("Undo"), "undo",
-                                           KStdAccel::shortcut(KStdAccel::Undo),
+    m_undoAction = new TDEToolBarPopupAction(i18n("Undo"), "edit-undo",
+                                           TDEStdAccel::shortcut(TDEStdAccel::Undo),
                                            TQT_TQOBJECT(m_canvas), TQT_SLOT(slotUndo()),
                                            actionCollection(), "editorwindow_undo");
 
@@ -319,8 +319,8 @@ void EditorWindow::setupStandardActions()
 
     m_undoAction->setEnabled(false);
 
-    m_redoAction = new KToolBarPopupAction(i18n("Redo"), "redo",
-                                           KStdAccel::shortcut(KStdAccel::Redo),
+    m_redoAction = new TDEToolBarPopupAction(i18n("Redo"), "edit-redo",
+                                           TDEStdAccel::shortcut(TDEStdAccel::Redo),
                                            TQT_TQOBJECT(m_canvas), TQT_SLOT(slotRedo()),
                                            actionCollection(), "editorwindow_redo");
 
@@ -332,7 +332,7 @@ void EditorWindow::setupStandardActions()
 
     m_redoAction->setEnabled(false);
 
-    d->selectAllAction = new KAction(i18n("Select All"),
+    d->selectAllAction = new TDEAction(i18n("Select All"),
                                      0,
                                      CTRL+Key_A,
                                      TQT_TQOBJECT(m_canvas),
@@ -340,7 +340,7 @@ void EditorWindow::setupStandardActions()
                                      actionCollection(),
                                      "editorwindow_selectAll");
 
-    d->selectNoneAction = new KAction(i18n("Select None"),
+    d->selectNoneAction = new TDEAction(i18n("Select None"),
                                      0,
                                      CTRL+SHIFT+Key_A,
                                      TQT_TQOBJECT(m_canvas),
@@ -356,18 +356,18 @@ void EditorWindow::setupStandardActions()
     d->zoomMinusAction = KStdAction::zoomOut(TQT_TQOBJECT(this), TQT_SLOT(slotDecreaseZoom()),
                                              actionCollection(), "editorwindow_zoomminus");
 
-    d->zoomTo100percents = new KAction(i18n("Zoom to 100%"), "viewmag1",
+    d->zoomTo100percents = new TDEAction(i18n("Zoom to 100%"), "zoom-original",
                                        ALT+CTRL+Key_0,      // NOTE: Photoshop 7 use ALT+CTRL+0.
                                        TQT_TQOBJECT(this), TQT_SLOT(slotZoomTo100Percents()),
                                        actionCollection(), "editorwindow_zoomto100percents");
 
 
-    d->zoomFitToWindowAction = new KToggleAction(i18n("Fit to &Window"), "view_fit_window",
+    d->zoomFitToWindowAction = new TDEToggleAction(i18n("Fit to &Window"), "view_fit_window",
                                        CTRL+SHIFT+Key_E,    // NOTE: Gimp 2 use CTRL+SHIFT+E.
                                        TQT_TQOBJECT(this), TQT_SLOT(slotToggleFitToWindow()),
                                        actionCollection(), "editorwindow_zoomfit2window");
 
-    d->zoomFitToSelectAction = new KAction(i18n("Fit to &Selection"), "viewmagfit",
+    d->zoomFitToSelectAction = new TDEAction(i18n("Fit to &Selection"), "zoom-fit-best",
                                          ALT+CTRL+Key_S, TQT_TQOBJECT(this), TQT_SLOT(slotFitToSelect()),
                                          actionCollection(), "editorwindow_zoomfit2select");
     d->zoomFitToSelectAction->setEnabled(false);
@@ -401,38 +401,38 @@ void EditorWindow::setupStandardActions()
             TQT_TQOBJECT(this), TQT_SLOT(slotZoomTextChanged(const TQString &)) );
 
     // Do not use std KDE action for full screen because action text is too large for app. toolbar.
-    m_fullScreenAction = new KToggleAction(i18n("Full Screen"), "window_fullscreen",
+    m_fullScreenAction = new TDEToggleAction(i18n("Full Screen"), "view-fullscreen",
                                            CTRL+SHIFT+Key_F, TQT_TQOBJECT(this),
                                            TQT_SLOT(slotToggleFullScreen()),
                                            actionCollection(), "editorwindow_fullscreen");
     m_fullScreenAction->setWhatsThis(i18n("Toggle the window to full screen mode"));
 
-    d->slideShowAction = new KAction(i18n("Slideshow"), "slideshow", Key_F9,
+    d->slideShowAction = new TDEAction(i18n("Slideshow"), "slideshow", Key_F9,
                                      TQT_TQOBJECT(this), TQT_SLOT(slotToggleSlideShow()),
                                      actionCollection(),"editorwindow_slideshow");
 
-    d->viewUnderExpoAction = new KToggleAction(i18n("Under-Exposure Indicator"), "underexposure",
+    d->viewUnderExpoAction = new TDEToggleAction(i18n("Under-Exposure Indicator"), "underexposure",
                                             Key_F10, TQT_TQOBJECT(this),
                                             TQT_SLOT(slotToggleUnderExposureIndicator()),
                                             actionCollection(),"editorwindow_underexposure");
 
-    d->viewOverExpoAction = new KToggleAction(i18n("Over-Exposure Indicator"), "overexposure",
+    d->viewOverExpoAction = new TDEToggleAction(i18n("Over-Exposure Indicator"), "overexposure",
                                             Key_F11, TQT_TQOBJECT(this),
                                             TQT_SLOT(slotToggleOverExposureIndicator()),
                                             actionCollection(),"editorwindow_overexposure");
 
-    d->viewCMViewAction = new KToggleAction(i18n("Color Managed View"), "tv",
+    d->viewCMViewAction = new TDEToggleAction(i18n("Color Managed View"), "tv",
                                             Key_F12, TQT_TQOBJECT(this),
                                             TQT_SLOT(slotToggleColorManagedView()),
                                             actionCollection(),"editorwindow_cmview");
 
     // -- Standard 'Transform' menu actions ---------------------------------------------
 
-    d->resizeAction = new KAction(i18n("&Resize..."), "resize_image", 0,
+    d->resizeAction = new TDEAction(i18n("&Resize..."), "resize_image", 0,
                                   TQT_TQOBJECT(this), TQT_SLOT(slotResize()),
                                   actionCollection(), "editorwindow_resize");
 
-    d->cropAction = new KAction(i18n("Crop"), "crop",
+    d->cropAction = new TDEAction(i18n("Crop"), "crop",
                                 CTRL+Key_X,
                                 TQT_TQOBJECT(m_canvas), TQT_SLOT(slotCrop()),
                                 actionCollection(), "editorwindow_crop");
@@ -443,26 +443,26 @@ void EditorWindow::setupStandardActions()
 
     // -- Standard 'Flip' menu actions ---------------------------------------------
 
-    d->flipHorizAction = new KAction(i18n("FlipQt::Horizontally"), "mirror", CTRL+Key_Asterisk,
+    d->flipHorizAction = new TDEAction(i18n("Flip Horizontally"), "mirror", CTRL+Key_Asterisk,
                                    TQT_TQOBJECT(m_canvas), TQT_SLOT(slotFlipHoriz()),
                                    actionCollection(), "editorwindow_flip_horiz");
     d->flipHorizAction->setEnabled(false);
 
-    d->flipVertAction = new KAction(i18n("FlipQt::Vertically"), "flip", CTRL+Key_Slash,
+    d->flipVertAction = new TDEAction(i18n("Flip Vertically"), "flip", CTRL+Key_Slash,
                                    TQT_TQOBJECT(m_canvas), TQT_SLOT(slotFlipVert()),
                                    actionCollection(), "editorwindow_flip_vert");
     d->flipVertAction->setEnabled(false);
 
     // -- Standard 'Rotate' menu actions ----------------------------------------
 
-    d->rotateLeftAction = new KAction(i18n("Rotate Left"),
-                                     "rotate_ccw", SHIFT+CTRL+Key_Left,
+    d->rotateLeftAction = new TDEAction(i18n("Rotate Left"),
+                                     "object-rotate-left", SHIFT+CTRL+Key_Left,
                                      TQT_TQOBJECT(m_canvas), TQT_SLOT(slotRotate270()),
                                      actionCollection(),
                                      "editorwindow_rotate_left");
     d->rotateLeftAction->setEnabled(false);
-    d->rotateRightAction  = new KAction(i18n("Rotate Right"),
-                                     "rotate_cw", SHIFT+CTRL+Key_Right,
+    d->rotateRightAction  = new TDEAction(i18n("Rotate Right"),
+                                     "object-rotate-right", SHIFT+CTRL+Key_Right,
                                      TQT_TQOBJECT(m_canvas), TQT_SLOT(slotRotate90()),
                                      actionCollection(),
                                      "editorwindow_rotate_right");
@@ -478,7 +478,7 @@ void EditorWindow::setupStandardActions()
 
     // -----------------------------------------------------------------------------------------
 
-    m_themeMenuAction = new KSelectAction(i18n("&Themes"), 0, actionCollection(), "theme_menu");
+    m_themeMenuAction = new TDESelectAction(i18n("&Themes"), 0, actionCollection(), "theme_menu");
     m_themeMenuAction->setItems(ThemeEngine::instance()->themeNames());
 
     connect(m_themeMenuAction, TQT_SIGNAL(activated(const TQString&)),
@@ -489,19 +489,19 @@ void EditorWindow::setupStandardActions()
 
     // -- Standard 'Help' menu actions ---------------------------------------------
 
-    d->donateMoneyAction = new KAction(i18n("Donate..."),
+    d->donateMoneyAction = new TDEAction(i18n("Donate..."),
                                        0, 0,
                                        TQT_TQOBJECT(this), TQT_SLOT(slotDonateMoney()),
                                        actionCollection(),
                                        "editorwindow_donatemoney");
 
-    d->contributeAction = new KAction(i18n("Contribute..."),
+    d->contributeAction = new TDEAction(i18n("Contribute..."),
                                       0, 0,
                                       TQT_TQOBJECT(this), TQT_SLOT(slotContribute()),
                                       actionCollection(),
                                       "editorwindow_contribute");
 
-    d->rawCameraListAction = new KAction(i18n("Supported RAW Cameras"),
+    d->rawCameraListAction = new TDEAction(i18n("Supported RAW Cameras"),
                                          "kdcraw",
                                          0,
                                          TQT_TQOBJECT(this),
@@ -512,7 +512,7 @@ void EditorWindow::setupStandardActions()
 
 void EditorWindow::setupStandardAccelerators()
 {
-    d->accelerators = new KAccel(this);
+    d->accelerators = new TDEAccel(this);
 
     d->accelerators->insert("Exit fullscreen", i18n("Exit Fullscreen mode"),
                     i18n("Exit out of the fullscreen mode"),
@@ -618,7 +618,7 @@ void EditorWindow::printImage(KURL url)
     DImg image(w, h, sixteenBit, hasAlpha, ptr);
 
     KPrinter printer;
-    TQString appName = KApplication::kApplication()->aboutData()->appName();
+    TQString appName = TDEApplication::kApplication()->aboutData()->appName();
     printer.setDocName( url.filename() );
     printer.setCreator( appName );
 #if KDE_IS_VERSION(3,2,0)
@@ -699,7 +699,7 @@ void EditorWindow::slotAboutToShowRedoMenu()
 
 void EditorWindow::slotConfToolbars()
 {
-    saveMainWindowSettings(KGlobal::config(), "ImageViewer Settings");
+    saveMainWindowSettings(TDEGlobal::config(), "ImageViewer Settings");
     KEditToolbar dlg(factory(), this);
 
     connect(&dlg, TQT_SIGNAL(newToolbarConfig()),
@@ -710,7 +710,7 @@ void EditorWindow::slotConfToolbars()
 
 void EditorWindow::slotNewToolbarConfig()
 {
-    applyMainWindowSettings(KGlobal::config(), "ImageViewer Settings");
+    applyMainWindowSettings(TDEGlobal::config(), "ImageViewer Settings");
 }
 
 void EditorWindow::slotIncreaseZoom()
@@ -757,7 +757,7 @@ void EditorWindow::slotZoomSelected()
 void EditorWindow::slotZoomTextChanged(const TQString &txt)
 {
     bool r      = false;
-    double zoom = KGlobal::locale()->readNumber(txt, &r) / 100.0;
+    double zoom = TDEGlobal::locale()->readNumber(txt, &r) / 100.0;
     if (r && zoom > 0.0)
         m_stackView->setZoomFactor(zoom);
 }
@@ -785,7 +785,7 @@ void EditorWindow::slotEscapePressed()
         m_fullScreenAction->activate();
 }
 
-void EditorWindow::plugActionAccel(KAction* action)
+void EditorWindow::plugActionAccel(TDEAction* action)
 {
     if (!action)
         return;
@@ -798,7 +798,7 @@ void EditorWindow::plugActionAccel(KAction* action)
                     TQT_SLOT(activate()));
 }
 
-void EditorWindow::unplugActionAccel(KAction* action)
+void EditorWindow::unplugActionAccel(TDEAction* action)
 {
     d->accelerators->remove(action->text());
 }
@@ -837,7 +837,7 @@ void EditorWindow::unLoadImagePlugins()
 
 void EditorWindow::readStandardSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
 
     // Restore full screen Mode ?
@@ -856,7 +856,7 @@ void EditorWindow::readStandardSettings()
 
 void EditorWindow::applyStandardSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
 
     // -- Settings for Color Management stuff ----------------------------------------------
 
@@ -966,7 +966,7 @@ void EditorWindow::applyStandardSettings()
 
 void EditorWindow::saveStandardSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
 
     config->writeEntry("AutoZoom", d->zoomFitToWindowAction->isChecked());
@@ -1050,11 +1050,11 @@ void EditorWindow::slotToggleFullScreen()
         topDock()->show();
         bottomDock()->show();
 
-        TQObject* obj = child("ToolBar","KToolBar");
+        TQObject* obj = child("ToolBar","TDEToolBar");
 
         if (obj)
         {
-            KToolBar* toolBar = static_cast<KToolBar*>(TQT_TQWIDGET(obj));
+            TDEToolBar* toolBar = static_cast<TDEToolBar*>(TQT_TQWIDGET(obj));
 
             if (m_fullScreenAction->isPlugged(toolBar) && d->removeFullScreenButton)
                 m_fullScreenAction->unplug(toolBar);
@@ -1096,11 +1096,11 @@ void EditorWindow::slotToggleFullScreen()
         rightDock()->hide();
         bottomDock()->hide();
 
-        TQObject* obj = child("ToolBar","KToolBar");
+        TQObject* obj = child("ToolBar","TDEToolBar");
 
         if (obj)
         {
-            KToolBar* toolBar = static_cast<KToolBar*>(TQT_TQWIDGET(obj));
+            TDEToolBar* toolBar = static_cast<TDEToolBar*>(TQT_TQWIDGET(obj));
 
             if (d->fullScreenHideToolBar)
             {
@@ -1255,9 +1255,9 @@ void EditorWindow::enter_loop()
 {
     TQWidget dummy(0, 0, WType_Dialog | WShowModal);
     dummy.setFocusPolicy( TQ_NoFocus );
-    qt_enter_modal(&dummy);
+    tqt_enter_modal(&dummy);
     tqApp->enter_loop();
-    qt_leave_modal(&dummy);
+    tqt_leave_modal(&dummy);
 }
 
 void EditorWindow::slotSelected(bool val)
@@ -1290,8 +1290,8 @@ void EditorWindow::slotSelected(bool val)
 
 void EditorWindow::hideToolBars()
 {
-    TQPtrListIterator<KToolBar> it = toolBarIterator();
-    KToolBar* bar;
+    TQPtrListIterator<TDEToolBar> it = toolBarIterator();
+    TDEToolBar* bar;
 
     for(;it.current()!=0L; ++it)
     {
@@ -1306,8 +1306,8 @@ void EditorWindow::hideToolBars()
 
 void EditorWindow::showToolBars()
 {
-    TQPtrListIterator<KToolBar> it = toolBarIterator();
-    KToolBar* bar;
+    TQPtrListIterator<TDEToolBar> it = toolBarIterator();
+    TDEToolBar* bar;
 
     for( ; it.current()!=0L ; ++it)
     {
@@ -1557,7 +1557,7 @@ bool EditorWindow::startingSaveAs(const KURL& url)
     imageFileSaveDialog.setFilter(mimetypes);
 
     TQFileInfo info(m_savingContext->srcURL.fileName());
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
     TQString ext      = config->readEntry("LastSavedImageTypeMime", "png");
     TQString fileName = info.baseName(false) + TQString(".") + ext;
@@ -1763,7 +1763,7 @@ void EditorWindow::slotToggleColorManagedView()
         // Save Color Managed View setting in config file. For performance
         // reason, no need to flush file, it cached in memory and will be flushed
         // to disk at end of session.
-        KConfig* config = kapp->config();
+        TDEConfig* config = kapp->config();
         config->setGroup("Color Management");
         config->writeEntry("ManagedView", cmv);
     }
@@ -1839,17 +1839,17 @@ void EditorWindow::setOverExposureToolTip(bool oei)
 
 void EditorWindow::slotDonateMoney()
 {
-    KApplication::kApplication()->invokeBrowser("http://www.digikam.org/?q=donation");
+    TDEApplication::kApplication()->invokeBrowser("http://www.digikam.org/?q=donation");
 }
 
 void EditorWindow::slotContribute()
 {
-    KApplication::kApplication()->invokeBrowser("http://www.digikam.org/?q=contrib");
+    TDEApplication::kApplication()->invokeBrowser("http://www.digikam.org/?q=contrib");
 }
 
 void EditorWindow::slotToggleSlideShow()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
     bool startWithCurrent = config->readBoolEntry("SlideShowStartCurrent", false);
 
@@ -1886,7 +1886,7 @@ void EditorWindow::slotThemeChanged()
 
     m_themeMenuAction->setCurrentItem(index);
 
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("ImageViewer Settings");
 
     if (!config->readBoolEntry("UseThemeBackgroundColor", true))
