@@ -39,25 +39,25 @@
 // KDE includes.
 
 #include <kcursor.h>
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
-#include <kmessagebox.h>
-#include <ktempfile.h>
+#include <tdeapplication.h>
+#include <tdemessagebox.h>
+#include <tdetempfile.h>
 #include <kimageio.h>
-#include <kfiledialog.h>
-#include <kdeversion.h>
-#include <kmenubar.h>
-#include <ktoolbar.h>
-#include <kaccel.h>
-#include <kaction.h>
-#include <kstdaccel.h>
+#include <tdefiledialog.h>
+#include <tdeversion.h>
+#include <tdemenubar.h>
+#include <tdetoolbar.h>
+#include <tdeaccel.h>
+#include <tdeaction.h>
+#include <tdestdaccel.h>
 #include <kstdaction.h>
 #include <kstdguiitem.h>
 #include <kstatusbar.h>
 #include <kprogress.h>
-#include <kwin.h>
+#include <twin.h>
 
 // Local includes.
 
@@ -129,17 +129,17 @@ public:
     KURL                      urlCurrent;
 
     // Rating actions.
-    KAction                  *star0;
-    KAction                  *star1;
-    KAction                  *star2;
-    KAction                  *star3;
-    KAction                  *star4;
-    KAction                  *star5;
+    TDEAction                  *star0;
+    TDEAction                  *star1;
+    TDEAction                  *star2;
+    TDEAction                  *star3;
+    TDEAction                  *star4;
+    TDEAction                  *star5;
 
     // Delete actions
-    KAction                  *fileDeletePermanentlyAction;
-    KAction                  *fileDeletePermanentlyDirectlyAction;
-    KAction                  *fileTrashDirectlyAction;
+    TDEAction                  *fileDeletePermanentlyAction;
+    TDEAction                  *fileDeletePermanentlyDirectlyAction;
+    TDEAction                  *fileTrashDirectlyAction;
 
     ImageInfoList             imageInfoList;
     ImageInfo                *imageInfoCurrent;
@@ -311,30 +311,30 @@ void ImageWindow::setupActions()
 
     // -- Rating actions ---------------------------------------------------------------
 
-    d->star0 = new KAction(i18n("Assign Rating \"No Stars\""), CTRL+Key_0,
+    d->star0 = new TDEAction(i18n("Assign Rating \"No Stars\""), CTRL+Key_0,
                           TQT_TQOBJECT(this), TQT_SLOT(slotAssignRatingNoStar()),
                           actionCollection(), "imageview_ratenostar");
-    d->star1 = new KAction(i18n("Assign Rating \"One Star\""), CTRL+Key_1,
+    d->star1 = new TDEAction(i18n("Assign Rating \"One Star\""), CTRL+Key_1,
                           TQT_TQOBJECT(this), TQT_SLOT(slotAssignRatingOneStar()),
                           actionCollection(), "imageview_rateonestar");
-    d->star2 = new KAction(i18n("Assign Rating \"Two Stars\""), CTRL+Key_2,
+    d->star2 = new TDEAction(i18n("Assign Rating \"Two Stars\""), CTRL+Key_2,
                           TQT_TQOBJECT(this), TQT_SLOT(slotAssignRatingTwoStar()),
                           actionCollection(), "imageview_ratetwostar");
-    d->star3 = new KAction(i18n("Assign Rating \"Three Stars\""), CTRL+Key_3,
+    d->star3 = new TDEAction(i18n("Assign Rating \"Three Stars\""), CTRL+Key_3,
                           TQT_TQOBJECT(this), TQT_SLOT(slotAssignRatingThreeStar()),
                           actionCollection(), "imageview_ratethreestar");
-    d->star4 = new KAction(i18n("Assign Rating \"Four Stars\""), CTRL+Key_4,
+    d->star4 = new TDEAction(i18n("Assign Rating \"Four Stars\""), CTRL+Key_4,
                           TQT_TQOBJECT(this), TQT_SLOT(slotAssignRatingFourStar()),
                           actionCollection(), "imageview_ratefourstar");
-    d->star5 = new KAction(i18n("Assign Rating \"Five Stars\""), CTRL+Key_5,
+    d->star5 = new TDEAction(i18n("Assign Rating \"Five Stars\""), CTRL+Key_5,
                           TQT_TQOBJECT(this), TQT_SLOT(slotAssignRatingFiveStar()),
                           actionCollection(), "imageview_ratefivestar");
 
     // -- Special Delete actions ---------------------------------------------------------------
 
     // Pop up dialog to ask user whether to permanently delete
-    d->fileDeletePermanentlyAction = new KAction(i18n("Delete File Permanently"),
-            "editdelete",
+    d->fileDeletePermanentlyAction = new TDEAction(i18n("Delete File Permanently"),
+            "edit-delete",
             SHIFT+Key_Delete,
             TQT_TQOBJECT(this),
             TQT_SLOT(slotDeleteCurrentItemPermanently()),
@@ -343,15 +343,15 @@ void ImageWindow::setupActions()
 
     // These two actions are hidden, no menu entry, no toolbar entry, no shortcut.
     // Power users may add them.
-    d->fileDeletePermanentlyDirectlyAction = new KAction(i18n("Delete Permanently without Confirmation"),
-            "editdelete",
+    d->fileDeletePermanentlyDirectlyAction = new TDEAction(i18n("Delete Permanently without Confirmation"),
+            "edit-delete",
             0,
             TQT_TQOBJECT(this),
             TQT_SLOT(slotDeleteCurrentItemPermanentlyDirectly()),
             actionCollection(),
             "image_delete_permanently_directly");
 
-    d->fileTrashDirectlyAction             = new KAction(i18n("Move to Trash without Confirmation"),
+    d->fileTrashDirectlyAction             = new TDEAction(i18n("Move to Trash without Confirmation"),
             "edittrash",
             0,
             TQT_TQOBJECT(this),
@@ -944,7 +944,7 @@ void ImageWindow::deleteCurrentItem(bool ask, bool permanently)
     u.setPath(d->urlCurrent.directory());
     PAlbum *palbum = AlbumManager::instance()->findPAlbum(u);
 
-    // if available, provide a digikamalbums:// URL to KIO
+    // if available, provide a digikamalbums:// URL to TDEIO
     KURL kioURL;
     if (d->imageInfoCurrent)
         kioURL = d->imageInfoCurrent->kurlForKIO();
