@@ -36,13 +36,13 @@
 
 // KDE includes.
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <ktabwidget.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kstandarddirs.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 
 // LibKDcraw includes.
 
@@ -197,16 +197,16 @@ RawSettingsBox::RawSettingsBox(const KURL& url, TQWidget *parent)
     TQPushButton *linHistoButton = new TQPushButton( d->scaleBG );
     TQToolTip::add( linHistoButton, i18n( "<p>Linear" ) );
     d->scaleBG->insert(linHistoButton, HistogramWidget::LinScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-lin", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    TQString directory = KGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
+    TDEGlobal::dirs()->addResourceType("histogram-lin", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    TQString directory = TDEGlobal::dirs()->findResourceDir("histogram-lin", "histogram-lin.png");
     linHistoButton->setPixmap( TQPixmap( directory + "histogram-lin.png" ) );
     linHistoButton->setToggleButton(true);
 
     TQPushButton *logHistoButton = new TQPushButton( d->scaleBG );
     TQToolTip::add( logHistoButton, i18n( "<p>Logarithmic" ) );
     d->scaleBG->insert(logHistoButton, HistogramWidget::LogScaleHistogram);
-    KGlobal::dirs()->addResourceType("histogram-log", KGlobal::dirs()->kde_default("data") + "digikam/data");
-    directory = KGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
+    TDEGlobal::dirs()->addResourceType("histogram-log", TDEGlobal::dirs()->kde_default("data") + "digikam/data");
+    directory = TDEGlobal::dirs()->findResourceDir("histogram-log", "histogram-log.png");
     logHistoButton->setPixmap( TQPixmap( directory + "histogram-log.png" ) );
     logHistoButton->setToggleButton(true);
 
@@ -249,7 +249,7 @@ RawSettingsBox::RawSettingsBox(const KURL& url, TQWidget *parent)
 
     d->abortBtn = new TQPushButton(d->rawdecodingBox);
     d->abortBtn->setText(i18n("Abort"));
-    d->abortBtn->setIconSet(SmallIconSet("stop"));
+    d->abortBtn->setIconSet(SmallIconSet("process-stop"));
     d->abortBtn->setEnabled(false);
     TQToolTip::add(d->abortBtn, i18n("Abort the current Raw image preview."));
 
@@ -390,7 +390,7 @@ RawSettingsBox::RawSettingsBox(const KURL& url, TQWidget *parent)
     TQToolTip::add(button(Ok), i18n("<p>Import image to editor using current settings."));
 
     button(Cancel)->setText(i18n("Use Default"));
-    button(Cancel)->setIconSet(SmallIconSet("gohome"));
+    button(Cancel)->setIconSet(SmallIconSet("go-home"));
     TQToolTip::add(button(Cancel), i18n("<p>Use general Raw decoding settings to load this image in editor."));
 
     // ---------------------------------------------------------------
@@ -507,7 +507,7 @@ CurvesWidget* RawSettingsBox::curve() const
 
 void RawSettingsBox::readSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("RAW Import Settings");
 
     d->channelCB->setCurrentItem(config->readNumEntry("Histogram Channel", RawSettingsBoxPriv::LuminosityChannel));
@@ -582,7 +582,7 @@ void RawSettingsBox::readSettings()
 
 void RawSettingsBox::writeSettings()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     config->setGroup("RAW Import Settings");
 
     config->writeEntry("Histogram Channel",          d->channelCB->currentItem());
