@@ -35,11 +35,11 @@
 
 // KDE includes.
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kdeversion.h>
-#include <kglobalsettings.h>
+#include <tdelocale.h>
+#include <tdeversion.h>
+#include <tdeglobalsettings.h>
 
 // Local includes.
 
@@ -104,7 +104,7 @@ SlideShow::SlideShow(const SlideShowSettings& settings)
     // ---------------------------------------------------------------
 
 #if KDE_IS_VERSION(3,2,0)
-    TQRect deskRect = KGlobalSettings::desktopGeometry(this);
+    TQRect deskRect = TDEGlobalSettings::desktopGeometry(this);
     d->deskX       = deskRect.x();
     d->deskY       = deskRect.y();
     d->deskWidth   = deskRect.width();
@@ -407,7 +407,7 @@ void SlideShow::updatePixmap()
             {
                 if (photoInfo.dateTime.isValid())
                 {
-                    str = KGlobal::locale()->formatDateTime(photoInfo.dateTime, true, true);
+                    str = TDEGlobal::locale()->formatDateTime(photoInfo.dateTime, true, true);
                     printInfoText(p, offset, str);
                 }
             }
@@ -438,8 +438,8 @@ void SlideShow::updatePixmap()
     {
         // End of Slide Show.
 
-        TQPixmap logo = kapp->iconLoader()->loadIcon("digikam", KIcon::NoGroup, 128,
-                                                    KIcon::DefaultState, 0, true);
+        TQPixmap logo = kapp->iconLoader()->loadIcon("digikam", TDEIcon::NoGroup, 128,
+                                                    TDEIcon::DefaultState, 0, true);
 
         TQFont fn(font());
         fn.setPointSize(fn.pointSize()+10);
